"use strict" ;

/**
 * Indicates if the specific <code>target</code> is an {@link system.data.Identifiable|Identifiable} object.
 * @name isIdentifiable
 * @memberof system.data
 * @function
 * @param {object} target - The object to evaluate.
 * @return A <code>true</code> value if the object is an {@link system.data.Identifiable|Identifiable} object.
 */
export function isIdentifiable( target )
{
    if( target )
    {
        return (target instanceof Identifiable) || ('id' in target) ;
    }
    return false ;
}

/**
 * This interface defines a common structure for <strong>identifiable</strong> classes (has an <code>id<code> property).
 * @name Identifiable
 * @interface
 * @memberof system.data
 */
export function Identifiable()
{
    Object.defineProperties( this ,
    {
        /**
         * Indicates the unique identifier value of this object.
         * @name id
         * @memberof system.data.Identifiable
         * @instance
         */
        id : { value : null , writable : true }
    }) ;
}

Identifiable.prototype = Object.create( Object.prototype ,
{
    constructor : { writable : true , value :  Identifiable }
}) ;